==> keri-0.6.7.tar.gz: keri-0.6.7/src/keri/app/challenging.py <==
# -*- encoding: utf-8 -*-
"""
keri.vc.challenging module

"""
import json

from hio.base import doing
from hio.help import decking


def loadHandlers(hby, exc, mbx, controller):
    """ Load handlers for the peer-to-peer challenge response protocol

    Parameters:
        hby (Habery): Database and keystore for environment
        exc (Exchanger): Peer-to-peer message router
        mbx (Mailboxer): Database for storing mailbox messages
        controller (str): qb64 identifier prefix of controller

    """
    chacha = ChallengeHandler(hby=hby, mbx=mbx, controller=controller)
    exc.addHandler(chacha)


class ChallengeHandler(doing.Doer):
    """  Handle challange response peer to peer `exn` message """

    resource = "/challenge/response"

    def __init__(self, hby, mbx, controller):
        """ Initialize peer to peer challange response messsage """

        self.hby = hby
        self.mbx = mbx
        self.controller = controller
        self.msgs = decking.Deck()
        self.cues = decking.Deck()
        super(ChallengeHandler, self).__init__()

    def do(self, tymth, *, tock=0.0, **opts):
        """  Do override to process incoming challenge responses

        Parameters:
            tymth (function): injected function wrapper closure returned by .tymen() of
                Tymist instance. Calling tymth() returns associated Tymist .tyme.
            tock (float): injected initial tock value

        """
        # start enter context
        self.wind(tymth)
        self.tock = tock
        yield self.tock

        while True:

            while self.msgs:
                msg = self.msgs.popleft()
                payload = msg["payload"]
                signer = msg["pre"]
                words = payload["words"]

                msg = dict(
                    r="/challenge",
                    signer=signer.qb64,
                    words=words
                )

                raw = json.dumps(msg).encode("utf-8")
                self.mbx.storeMsg(self.controller+"/challenge", raw)

                yield self.tock
            yield self.tock

==> keri-1.0.0.tar.gz: keri-1.0.0/src/keri/app/challenging.py <==
# -*- encoding: utf-8 -*-
"""
keri.vc.challenging module

"""

from hio.base import doing
from hio.help import decking


def loadHandlers(db, signaler, exc):
    """ Load handlers for the peer-to-peer challenge response protocol

    Parameters:
        db (Baser): database environment
        signaler (Signaler): Signaler for transient messages for the controller of the agent
        exc (Exchanger): Peer-to-peer message router

    """
    chacha = ChallengeHandler(db=db, signaler=signaler)
    exc.addHandler(chacha)


class ChallengeHandler(doing.Doer):
    """  Handle challange response peer to peer `exn` message """

    resource = "/challenge/response"
    persist = True

    def __init__(self, db, signaler):
        """ Initialize peer to peer challange response messsage """

        self.db = db
        self.msgs = decking.Deck()
        self.cues = decking.Deck()
        self.signaler = signaler
        super(ChallengeHandler, self).__init__()

    def do(self, tymth, *, tock=0.0, **opts):
        """  Do override to process incoming challenge responses

        Parameters:
            tymth (function): injected function wrapper closure returned by .tymen() of
                Tymist instance. Calling tymth() returns associated Tymist .tyme.
            tock (float): injected initial tock value

        """
        # start enter context
        self.wind(tymth)
        self.tock = tock
        yield self.tock

        while True:

            while self.msgs:
                msg = self.msgs.popleft()
                payload = msg["payload"]
                signer = msg["pre"]
                words = payload["words"]

                serder = msg["serder"]

                msg = dict(
                    signer=signer.qb64,
                    said=serder.said,
                    words=words
                )

                # Notify controller of sucessful challenge
                self.signaler.push(msg, topic="/challenge")

                # Log signer against event to track successful challenges with signed response
                self.db.reps.add(keys=(signer.qb64,), val=serder.saider)

                yield self.tock
            yield self.tock
